==> node-autoprefixer_7.2.5.orig.tar.gz: autoprefixer-7.2.5/lib/browsers.js <==
const browserslist = require('browserslist');

const utils = require('./utils');

class Browsers {

    /**
     * Return all prefixes for default browser data
     */
    static prefixes() {
        if (this.prefixesCache) {
            return this.prefixesCache;
        }

        const data = require('caniuse-lite').agents;

        this.prefixesCache = [];
        for (const name in data) {
            this.prefixesCache.push(`-${data[name].prefix}-`);
        }

        this.prefixesCache = utils
            .uniq(this.prefixesCache)
            .sort((a, b) => b.length - a.length);

        return this.prefixesCache;
    }

    /**
     * Check is value contain any possibe prefix
     */
    static withPrefix(value) {
        if (!this.prefixesRegexp) {
            this.prefixesRegexp = new RegExp(this.prefixes().join('|'));
        }

        return this.prefixesRegexp.test(value);
    }

    constructor(data, requirements, options, stats) {
        this.data = data;
        this.options = options || {};
        this.stats = stats;
        this.selected = this.parse(requirements);
    }

    /**
     * Return browsers selected by requirements
     */
    parse(requirements) {
        return browserslist(requirements, {
            stats: this.stats,
            path: this.options.from,
            env: this.options.env
        });
    }

    /**
     * Return prefix for selected browser
     */
    prefix(browser) {
        const [name, version] = browser.split(' ');
        const data     = this.data[name];

        let prefix = data.prefix_exceptions && data.prefix_exceptions[version];
        if (!prefix) {
            prefix = data.prefix;
        }
        return `-${prefix}-`;
    }

    /**
     * Is browser is selected by requirements
     */
    isSelected(browser) {
        return this.selected.indexOf(browser) !== -1;
    }

}

module.exports = Browsers;

==> node-autoprefixer_8.6.5.orig.tar.gz: autoprefixer-8.6.5/lib/browsers.js <==
const browserslist = require('browserslist');

const utils = require('./utils');

class Browsers {

    /**
     * Return all prefixes for default browser data
     */
    static prefixes() {
        if (this.prefixesCache) {
            return this.prefixesCache;
        }

        const data = require('caniuse-lite').agents;

        this.prefixesCache = [];
        for (const name in data) {
            this.prefixesCache.push(`-${data[name].prefix}-`);
        }

        this.prefixesCache = utils
            .uniq(this.prefixesCache)
            .sort((a, b) => b.length - a.length);

        return this.prefixesCache;
    }

    /**
     * Check is value contain any possibe prefix
     */
    static withPrefix(value) {
        if (!this.prefixesRegexp) {
            this.prefixesRegexp = new RegExp(this.prefixes().join('|'));
        }

        return this.prefixesRegexp.test(value);
    }

    constructor(data, requirements, options, browserslistOpts) {
        this.data = data;
        this.options = options || {};
        this.browserslistOpts = browserslistOpts || { };
        this.selected = this.parse(requirements);
    }

    /**
     * Return browsers selected by requirements
     */
    parse(requirements) {
        const opts = { };
        for (const i in this.browserslistOpts) {
            opts[i] = this.browserslistOpts[i];
        }
        opts.path = this.options.from;
        opts.env = this.options.env;
        return browserslist(requirements, opts);
    }

    /**
     * Return prefix for selected browser
     */
    prefix(browser) {
        const [name, version] = browser.split(' ');
        const data     = this.data[name];

        let prefix = data.prefix_exceptions && data.prefix_exceptions[version];
        if (!prefix) {
            prefix = data.prefix;
        }
        return `-${prefix}-`;
    }

    /**
     * Is browser is selected by requirements
     */
    isSelected(browser) {
        return this.selected.indexOf(browser) !== -1;
    }

}

module.exports = Browsers;
